@@ -70,7 +70,11 @@
 )]
 // END - Embark standard lints v0.4
 // BEGIN - Ark-specific lints
-#![warn(clippy::flat_map_option)]
+#![warn(
+    clippy::flat_map_option,
+    clippy::disallowed_method,
+    clippy::disallowed_type
+)]
 // END - Ark-specific lints
 
 // crate-specific exceptions:
@@ -115,8 +119,7 @@ pub use quat_ext::*;
 pub mod prelude {
     pub use {
         crate::FloatExt, crate::Mat3Ext, crate::Mat4Ext, crate::Vec2Ext, crate::Vec2Swizzles,
-        crate::Vec3Ext, crate::Vec3ExtSpirv, crate::Vec3Swizzles, crate::Vec4Ext,
-        crate::Vec4Swizzles,
+        crate::Vec3Ext, crate::Vec3Swizzles, crate::Vec4Ext, crate::Vec4Swizzles,
     };
 
     #[cfg(not(target_arch = "spirv"))]
@@ -127,7 +130,7 @@ pub mod prelude {
 // Should we change to re-export all?
 pub use glam::{
     const_mat2, const_mat3, const_mat4, const_quat, const_vec2, const_vec3, const_vec4, ivec2,
-    mat2, mat3, mat4, quat, uvec2, uvec3, uvec4, vec2, vec3, vec4, Affine3A, EulerRot, IVec2,
-    IVec3, IVec4, Mat2, Mat3, Mat4, Quat, UVec2, UVec3, UVec4, Vec2, Vec2Swizzles, Vec3, Vec3A,
-    Vec3Swizzles, Vec4, Vec4Swizzles,
+    ivec3, mat2, mat3, mat4, quat, uvec2, uvec3, uvec4, vec2, vec3, vec4, Affine3A, EulerRot,
+    IVec2, IVec3, IVec4, Mat2, Mat3, Mat4, Quat, UVec2, UVec3, UVec4, Vec2, Vec2Swizzles, Vec3,
+    Vec3A, Vec3Swizzles, Vec4, Vec4Swizzles,
 };
