@@ -2,7 +2,7 @@ use super::prelude::*;
 use super::{vec2, Vec2};
 
 #[cfg(target_arch = "spirv")]
-use spirv_std::num_traits::Float;
+use num_traits::Float;
 
 /// Extensions to [`Vec2`]
 ///
