@@ -2,10 +2,7 @@ use super::prelude::*;
 use super::{vec3, Vec3};
 
 #[cfg(target_arch = "spirv")]
-use spirv_std::num_traits::Float;
-
-#[cfg(target_arch = "spirv")]
-use spirv_std::arch;
+use num_traits::Float;
 
 /// Extensions to [`Vec3`]
 ///
@@ -64,51 +61,6 @@ impl Vec3Ext for Vec3 {
     }
 }
 
-/// Extensions to [`Vec3`] specific to SPIR-V
-///
-/// Adds additional functionality to [`Vec3`] that [`glam`] doesn't have.
-pub trait Vec3ExtSpirv {
-    /// The derivative of self with respect to the nearest fragments on the x axis. Only defined within a fragment shader.
-    fn ddx(self) -> Self;
-
-    /// The derivative of self with respect to the nearest fragments on the y axis. Only defined within a fragment shader.
-    fn ddy(self) -> Self;
-
-    /// The sum of the absolute derivative in x and y. Only defined within a fragment shader.
-    fn fwidth(self) -> Self;
-}
-
-#[cfg(target_arch = "spirv")]
-impl Vec3ExtSpirv for Vec3 {
-    fn ddx(self) -> Vec3 {
-        arch::ddx_vector(self)
-    }
-
-    fn ddy(self) -> Vec3 {
-        arch::ddy_vector(self)
-    }
-
-    fn fwidth(self) -> Vec3 {
-        arch::fwidth_vector(self)
-    }
-}
-
-#[cfg(not(target_arch = "spirv"))]
-#[allow(clippy::unimplemented)] // this can't easily be implemented on CPU
-impl Vec3ExtSpirv for Vec3 {
-    fn ddx(self) -> Self {
-        unimplemented!();
-    }
-
-    fn ddy(self) -> Self {
-        unimplemented!();
-    }
-
-    fn fwidth(self) -> Self {
-        unimplemented!();
-    }
-}
-
 /// Coordinate system extension to [`Vec3`]
 ///
 /// This crate is opinionated  with what coordinate system it uses and this adds
