@@ -1,7 +1,7 @@
 use super::{uvec4, vec4, UVec4, Vec4};
 
 #[cfg(target_arch = "spirv")]
-use spirv_std::num_traits::Float;
+use num_traits::Float;
 
 /// Extensions to [`Vec4`]
 ///
